#
# spec file for package paho-mqtt-c
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sover 1
Name:           paho-mqtt-c
Version:        1.3.13
Release:        2.3
Summary:        MQTT C Client
License:        BSD-3-Clause AND EPL-1.0
URL:            https://eclipse.org/paho/clients/c/
Source:         https://github.com/eclipse/paho.mqtt.c/archive/v%{version}.tar.gz#/paho.mqtt.c-%{version}.tar.gz
BuildRequires:  cmake
BuildRequires:  fdupes
BuildRequires:  gcc
BuildRequires:  openssl-devel
Requires:       openssl

%description
The Paho MQTT C Client is a fully featured MQTT client written in ANSI standard C.

%package -n libpaho-mqtt%{sover}
Summary:        Library implementing the MQTT client

%description  -n libpaho-mqtt%{sover}
The Paho MQTT C Client is a fully featured MQTT client written in ANSI standard C.
C was chosen rather than C++ to maximize portability. A C++ API over this library is also available in Paho.

%package -n libpaho-mqtt-devel
Summary:        Development files for MQTT C Client library
Requires:       libpaho-mqtt%{sover} = %{version}

%description -n libpaho-mqtt-devel
Development files for the the Paho MQTT C Client.

%prep
%setup -q -n paho.mqtt.c-%{version}

%build
%cmake -DPAHO_WITH_SSL=TRUE -DPAHO_BUILD_DOCUMENTATION=FALSE -DPAHO_BUILD_SAMPLES=FALSE -DPAHO_ENABLE_TESTING=FALSE -DPAHO_ENABLE_CPACK=FALSE ..
%make_build

%install
%cmake_install

%post -n libpaho-mqtt%{sover} -p /sbin/ldconfig
%postun -n libpaho-mqtt%{sover} -p /sbin/ldconfig

%files -n libpaho-mqtt%{sover}
%license LICENSE edl-v10 epl-v20
%{_libdir}/*.so.%{version}
%{_libdir}/*.so.1

%files -n libpaho-mqtt-devel
%doc README.md
%{_bindir}/MQTTVersion
%{_includedir}/*
%{_libdir}/*.so
%{_docdir}/*
%{_libdir}/cmake/*

%changelog
* Wed Apr 10 2024 Danilo Spinella <danilo.spinella@suse.com>
- The documentation isn't built anymore, fix spec file accordingly.
* Sat Nov 25 2023 Dirk Müller <dmueller@suse.com>
- update to 1.3.13:
  * Service release. Issues fixed:
    https://github.com/eclipse/paho.mqtt.c/milestone/20?closed=1
* Wed Jan  4 2023 Dirk Müller <dmueller@suse.com>
- update to 1.3.12:
  * service release
  * https://github.com/eclipse/paho.mqtt.c/milestone/19?closed=1
* Wed Apr 20 2022 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to 1.3.10
  * Use poll system call instead of select to monitor sockets
  * Bug fixes
  * https://github.com/eclipse/paho.mqtt.c/milestone/17?closed=1
* Mon Jul 19 2021 Danilo Spinella <danilo.spinella@suse.com>
- Update to 1.3.9:
  * Fix old security issue
  * Bug fixes
  * https://github.com/eclipse/paho.mqtt.c/milestone/16?closed=1
- Remove cmake-libdir.patch as it as been upstreamed
* Mon May 17 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to 1.3.8
  * Added Proxy support
  * Fixed token not increased when using QOS0
  * Fixed base64 encoding for basic auth proxy
  * Fixed OpenSSL Crash during MQTTClient_destroy
  * Fixed Crash while loading persisted messages
  * Fixed multiple MQTT client crashes
* Mon Aug 17 2020 Dirk Mueller <dmueller@suse.com>
- update to 1.3.5:
  * Focus on persistence
  * Fixes
  * Bugfixes
  * https://github.com/eclipse/paho.mqtt.c/milestone/8?closed=1
  * https://github.com/eclipse/paho.mqtt.c/milestone/7?closed=1
  * https://github.com/eclipse/paho.mqtt.c/milestone/6?closed=1
- add cmake-libdir.patch to fix cmake module installation on x86_64
* Thu Mar 19 2020 Kristyna Streitova <kstreitova@suse.com>
- re-download upstream tarball
* Tue Mar 17 2020 Kristyna Streitova <kstreitova@suse.com>
- add BSD-3-Clause (EDL) license
- run spec-cleaner and remove Group tag
- use %%fdupes macro for replacing duplicates in doc by soft links
- rename package to paho-mqtt-c and subpackage to libpaho-mqtt
* Fri Jan 17 2020 Ann Davis <andavis@suse.com>
- Re-build for Package Hub.
* Fri Aug 23 2019 Vladislav Zverev <vladspbru@yandex.ru>
- initial packaging v1.3.1 for open build service [jsc#ECO-1126]
